searchData={"items":[{"type":"module","title":"Mjml","doc":"Provides functions for transpiling MJML email templates to HTML.","ref":"Mjml.html"},{"type":"function","title":"Mjml.to_html/2","doc":"Converts an MJML string to HTML content.\n\nReturns a result tuple:\n\n* `{:ok, html}` for a successful MJML transpiling\n* `{:error, message}` for a failed MJML transpiling\n\nYou can pass render options to customize the rendering of the final HTML:\n\n* `keep_comments` – when `false`, removes the comments from the rendered HTML.\n  Defaults to `true`.\n\n* `social_icon_path` – when given, uses this base path to generate social icon URLs.\n  E.g. `social_icon_path: \"https://example.com/icons/\"` will generate a social icon\n  URL, like \"https://example.com/icons/github.png\"\n\n* `fonts` – a Map of font names and their URLs to hosted CSS files.\n  When given, includes these fonts in the rendered HTML\n  (Note that only actually used fonts will show up!).\n  Defaults to `nil`, which will make the default font families available to\n  be used (Open Sans, Droid Sans, Lato, Roboto, and Ubuntu).","ref":"Mjml.html#to_html/2"},{"type":"function","title":"Examples - Mjml.to_html/2","doc":"iex> Mjml.to_html(\"    \")\n    {:ok, \"<!doctype html>  Mjml.to_html(\"something not MJML\")\n    {:error, \"Couldn't convert MJML template\"}\n\n    iex> opts = [\n    iex>   keep_comments: false,\n    iex>   social_icon_path: \"https://example.com/icons/\"\n    iex>   fonts: %{\n    iex>     \"Noto Color Emoji\": \"https://fonts.googleapis.com/css?family=Noto+Color+Emoji:400\"\n    iex>   }\n    iex> ]\n    iex> Mjml.to_html(\"    \", opts)\n    {:ok, \"<!doctype html><html xmlns=...\"}","ref":"Mjml.html#to_html/2-examples"},{"type":"module","title":"Mjml.Native","doc":"","ref":"Mjml.Native.html"},{"type":"function","title":"Mjml.Native.to_html/2","doc":"","ref":"Mjml.Native.html#to_html/2"},{"type":"module","title":"Mjml.RenderOptions","doc":"","ref":"Mjml.RenderOptions.html"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)\nand this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).\n\nFor clarity, major releases of mjml_nif use the respective [mrml] releases with the same major release number.\nI.e. `mjml_nif 0.x` versions use mrml versions `>= 0.1, < 1.0.0`, and `mjml_nif 1.x` versions use mrml versions `>= 1.0.0, < 2.0.0`, etc.\n\n## [Unreleased]\n\n## [3.0.2] - 2024-02-27\n\n- Use [mrml] v3.0.2, which fixes using comments in ` ` tags. (See https://github.com/jdrouet/mrml/issues/373, [mrml diff v3.0.1..v3.0.2][mrml-v3.0.1-v3.0.2]).\n\n\n## [3.0.1] - 2024-02-16\n\n- Use [mrml] v3.0.1, which fixes using comments in ` ` tags. (See https://github.com/jdrouet/mrml/issues/370, [mrml diff v3.0.0..v3.0.1][mrml-v3.0.0-v3.0.1]).\n\n\n## [3.0.0] - 2023-12-23","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"- Use [mrml] v3.0.0, which fixes an issue with rendering not self-closing `  ` tags. (See https://github.com/jdrouet/mrml/issues/356, [mrml diff v2.1.1..v3.0.0][mrml-v2.1.1-v3.0.0]).\n\n## [2.0.0] - 2023-12-16\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Drop support for Elixir < v1.13\n- Drop `arm-unknown-linux-gnueabihf` as precompiled target\n- Allow passing a rendering option `fonts` to `Mjml.to_html/2`\n- Use [Rustler Precompiled v0.7.1](https://github.com/philss/rustler_precompiled/blob/main/CHANGELOG.md#071---2023-11-30)\n- Use rustler v0.30.0\n- Use Rust edition 2021\n- Use [mrml] v.2.1.1, which provides a `fonts` rendering option and implements mj-include (see [mrml diff v1.2.11..v2.1.1][mrml-v1.2.11-v2.1.1])\n\n---\n\n## [1.5.0] - 2023-02-02\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Use rustler_precompiled v0.6.0\n- Add new target `riscv64gc-unknown-linux-gnu`\n- Use [mrml] v1.2.11, which handles inner attributes (see [mrml diff v1.2.10..v1.2.11][mrml-v1.2.10-v1.2.11])\n\n## [1.4.0] - 2022-11-30\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Use rustler_precompiled v0.5.4\n- Change `Mjml.to_html/1` to `Mjml.to_html/2` and allow passing rendering options `keep_comments` (defaults to `true`) & `social_icon_path`\n\n## [1.3.5] - 2022-07-11\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Add `aarch64-unknown-linux-musl` as precompiled target (see [#66](https://github.com/adoptoposs/mjml_nif/issues/66))\n\n## [1.3.4] - 2022-07-01\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Add Cross.toml in order to pass the NIF version to cross (see [philss/rustler_precompiled#23](https://github.com/philss/rustler_precompiled/issues/23))\n\n## [1.3.3] - 2022-05-25\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Use \"orderedmap\" feature of mrml to get consistent HTML output (see [jdrouet/mrml#215](https://github.com/jdrouet/mrml/pull/215))\n- Use [Rustler Precompiled v0.5.1](https://github.com/philss/rustler_precompiled/blob/main/CHANGELOG.md#051---2022-05-24)\n\n## [1.3.2] - 2022-03-26\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Use [mrml] v1.2.10, which fixes a bug with parsing other self-closing tags\n(see [mrml diff v1.2.9..v1.2.10][mrml-v1.2.9-v1.2.10]))\n\n## [1.3.1] - 2022-03-25\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Use [mrml] v1.2.9, which fixes a bug with parsing the self-closing `br` and `meta` tags\n(see [mrml diff v1.2.8..v1.2.9][mrml-v1.2.8-v1.2.9]))\n\n## [1.3.0] - 2022-03-18\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Use [Rustler Precompiled](https://github.com/philss/rustler_precompiled): this allows to use the mjml NIF without the Rust compiler 🎉\n- Use [mrml] v1.2.8 (see [mrml diff v1.2.7..v1.2.8][mrml-v1.2.7-v1.2.8]))\n\n## [1.2.0] - 2022-02-25\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Update rustler to v0.24 (drops support for OTP <22, requires Elixir ~> 1.11)\n\n## [1.1.3] - 2022-02-16\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Update rustler to v0.23 (drops support for OTP 20)\n- Use [mrml] v1.2.7, which allows inner elements in mj-social-element & mj-navbar-link (see [mrml diff v1.2.5..v1.2.7][mrml-v1.2.5-v1.2.7])\n\n## [1.1.2] - 2021-10-04\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Use [mrml] v1.2.5, which allows the `lang` attribute in the mjml tag and allows using `mj-raw` tags in `mj-head` (see [mrml diff v1.2.3..v1.2.5][mrml-v1.2.3-v1.2.5])\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Misc doc changes ([#31](https://github.com/adoptoposs/mjml_nif/pull/31))\n\n## [1.1.1] - 2021-06-01\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Use [mrml] v1.2.3, which fixes a bug with ignored mj-class attributes (see [jdrouet/mrml #164](https://github.com/jdrouet/mrml/issues/164), [mrml diff v1.2.2..v1.2.3][mrml-v1.2.2-v1.2.3]))\n\n## [1.1.0] - 2021-05-23\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Use [mrml] v1.2.2\n- Support OTP 24\n- mjml_nif crate type changed from \"dylib\" to \"cdylib\"\n\n## [1.0.0] - 2021-04-07\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Use [mrml] v1.0.0\n- Pass on parsing/rendering error messages from mrml to the error tuple of `MJML.to_html/1`\n\n## [0.3.1] - 2021-02-23\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Compilation on aarch64 MacOS\n\n## [0.3.0] - 2021-02-02\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Use [mrml] v0.5.0\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Warning about special link args for x86_64-apple-darwin target\n\n## [0.2.0] – 2020-10-19\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Use [mrml] v0.3.3\n\n## [0.1.0] – 2020-07-19\nInitial release\n\n[Unreleased]: https://github.com/adoptoposs/mjml_nif/compare/v3.0.2...HEAD\n[3.0.2]: https://github.com/adoptoposs/mjml_nif/compare/v3.0.1...v3.0.2\n[3.0.1]: https://github.com/adoptoposs/mjml_nif/compare/v3.0.0...v3.0.1\n[3.0.0]: https://github.com/adoptoposs/mjml_nif/compare/v2.0.0...v3.0.0\n[2.0.0]: https://github.com/adoptoposs/mjml_nif/compare/v1.5.0...v2.0.0\n[1.5.0]: https://github.com/adoptoposs/mjml_nif/compare/v1.4.0...v1.5.0\n[1.4.0]: https://github.com/adoptoposs/mjml_nif/compare/v1.3.5...v1.4.0\n[1.3.5]: https://github.com/adoptoposs/mjml_nif/compare/v1.3.4...v1.3.5\n[1.3.4]: https://github.com/adoptoposs/mjml_nif/compare/v1.3.3...v1.3.4\n[1.3.3]: https://github.com/adoptoposs/mjml_nif/compare/v1.3.2...v1.3.3\n[1.3.2]: https://github.com/adoptoposs/mjml_nif/compare/v1.3.1...v1.3.2\n[1.3.1]: https://github.com/adoptoposs/mjml_nif/compare/v1.3.0...v1.3.1\n[1.3.0]: https://github.com/adoptoposs/mjml_nif/compare/v1.2.0...v1.3.0\n[1.2.0]: https://github.com/adoptoposs/mjml_nif/compare/v1.1.3...v1.2.0\n[1.1.3]: https://github.com/adoptoposs/mjml_nif/compare/v1.1.2...v1.1.3\n[1.1.2]: https://github.com/adoptoposs/mjml_nif/compare/v1.1.1...v1.1.2\n[1.1.1]: https://github.com/adoptoposs/mjml_nif/compare/v1.1.0...v1.1.1\n[1.1.0]: https://github.com/adoptoposs/mjml_nif/compare/v1.0.0...v1.1.0\n[1.0.0]: https://github.com/adoptoposs/mjml_nif/compare/v0.3.1...v1.0.0\n[0.3.1]: https://github.com/adoptoposs/mjml_nif/compare/v0.3.0...v0.3.1\n[0.3.0]: https://github.com/adoptoposs/mjml_nif/compare/v0.2.0...v0.3.0\n[0.2.0]: https://github.com/adoptoposs/mjml_nif/compare/v0.1.0...v0.2.0\n[0.1.0]: https://github.com/adoptoposs/mjml_nif/compare/e77d33e9bcb58e0e2e9e522322d97ebdcb212618...v0.1.0\n[mrml]: https://github.com/jdrouet/mrml\n\n[mrml-v3.0.1-v3.0.2]: https://github.com/jdrouet/mrml/compare/mrml-v3.0.1...mrml-v3.0.2\n[mrml-v3.0.0-v3.0.1]: https://github.com/jdrouet/mrml/compare/mrml-v3.0.0...mrml-v3.0.1\n[mrml-v2.1.1-v3.0.0]: https://github.com/jdrouet/mrml/compare/mrml-v2.1.1...mrml-v3.0.0\n[mrml-v1.2.11-v2.1.1]: https://github.com/jdrouet/mrml/compare/v1.2.11...mrml-v2.1.1\n[mrml-v1.2.10-v1.2.11]: https://github.com/jdrouet/mrml/compare/mrml-core-1.2.10...v1.2.11\n[mrml-v1.2.9-v1.2.10]: https://github.com/jdrouet/mrml/compare/mrml-core-1.2.9...mrml-core-1.2.10\n[mrml-v1.2.8-v1.2.9]: https://github.com/jdrouet/mrml/compare/mrml-core-1.2.8...mrml-core-1.2.9\n[mrml-v1.2.7-v1.2.8]: https://github.com/jdrouet/mrml/compare/mrml-core-1.2.7...mrml-core-1.2.8\n[mrml-v1.2.5-v1.2.7]: https://github.com/jdrouet/mrml/compare/mrml-core-1.2.5...mrml-core-1.2.7\n[mrml-v1.2.3-v1.2.5]: https://github.com/jdrouet/mrml/compare/mrml-core-1.2.3...mrml-core-1.2.5\n[mrml-v1.2.2-v1.2.3]: https://github.com/jdrouet/mrml/compare/mrml-core-1.2.2...mrml-core-1.2.3","ref":"changelog.html#changed"},{"type":"extras","title":"Contributing","doc":"# Contributing to mjml_nif\n\nThanks for considering to contribute to mjml_nif. ❤\n\nBug reports, feature suggestions, and pull requests for any open issues are very welcome. Issues can be reported on GitHub: https://github.com/adoptoposs/mjml_nif/issues/new.\n\nPlease read and follow our [Code of Conduct](https://github.com/adoptoposs/mjml_nif/blob/main/CODE_OF_CONDUCT.md).","ref":"contributing.html"},{"type":"extras","title":"Development setup - Contributing","doc":"In order to setup the development environment you need to have some dependencies installed on your machine:\n\n- [git](https://git-scm.com/downloads)\n- [Rust](https://www.rust-lang.org/learn/get-started)\n- [Elixir](https://elixir-lang.org/install.html)\n\nCheckout the mjml_nif repository with\n\n```\n$ git clone git@github.com:adoptoposs/mjml_nif.git\n```\n\nThen step into the project directory and install the dependencies with \n\n```\nmix deps.get\n```","ref":"contributing.html#development-setup"},{"type":"extras","title":"How to Contribute - Contributing","doc":"Here’s how to contribute:\n\n* Fork it (https://github.com/adoptoposs/mjml_nif/fork)\n* Create your feature branch (git checkout -b feature/my-new-feature)\n* Commit your changes (git commit -am 'Add some feature')\n* Push to the branch (git push origin feature/my-new-feature)\n* Create a new Pull Request\n\nTry to add tests along with your new feature. This will ensure that your code does not break existing functionality and that your feature is working as expected. You can run the tests with:\n\n```bash\nmix test\n```\n\nIf you’ve changed any Elixir code, please run Elixir’s code formatter before committing your changes:\n\n```bash\nmix format\n```\n\nThis will keep the code style consistent and future code diffs as small as possible.","ref":"contributing.html#how-to-contribute"},{"type":"extras","title":"Publishing a new package version - Contributing","doc":"For detailed info about what needs to be done in order to publish a new version of\nthe mjml package on hex.pm, please refer to the release flow section in the\n[precompilation guide](https://hexdocs.pm/rustler_precompiled/precompilation_guide.html)\nof `rustler_precompiled`.\n\n---------\n\nAs a contributor, please keep in mind this project is free and open source software. Maintainers are not paid to work on it, so there might be times were the maintainers seem unresponsive. If you have that feeling, please be patient and be assured, that all team members try their best to review your contribution and reply to you as soon as their time allows.","ref":"contributing.html#publishing-a-new-package-version"},{"type":"extras","title":"Code of Conduct","doc":"# Contributor Covenant Code of Conduct","ref":"code_of_conduct.html"},{"type":"extras","title":"Our Pledge - Code of Conduct","doc":"We as members, contributors, and leaders pledge to make participation in our\ncommunity a harassment-free experience for everyone, regardless of age, body\nsize, visible or invisible disability, ethnicity, sex characteristics, gender\nidentity and expression, level of experience, education, socio-economic status,\nnationality, personal appearance, race, religion, or sexual identity\nand orientation.\n\nWe pledge to act and interact in ways that contribute to an open, welcoming,\ndiverse, inclusive, and healthy community.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Our Standards - Code of Conduct","doc":"Examples of behavior that contributes to a positive environment for our\ncommunity include:\n\n* Demonstrating empathy and kindness toward other people\n* Being respectful of differing opinions, viewpoints, and experiences\n* Giving and gracefully accepting constructive feedback\n* Accepting responsibility and apologizing to those affected by our mistakes,\n  and learning from the experience\n* Focusing on what is best not just for us as individuals, but for the\n  overall community\n\nExamples of unacceptable behavior include:\n\n* The use of sexualized language or imagery, and sexual attention or\n  advances of any kind\n* Trolling, insulting or derogatory comments, and personal or political attacks\n* Public or private harassment\n* Publishing others' private information, such as a physical or email\n  address, without their explicit permission\n* Other conduct which could reasonably be considered inappropriate in a\n  professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Enforcement Responsibilities - Code of Conduct","doc":"Community leaders are responsible for clarifying and enforcing our standards of\nacceptable behavior and will take appropriate and fair corrective action in\nresponse to any behavior that they deem inappropriate, threatening, offensive,\nor harmful.\n\nCommunity leaders have the right and responsibility to remove, edit, or reject\ncomments, commits, code, wiki edits, issues, and other contributions that are\nnot aligned to this Code of Conduct, and will communicate reasons for moderation\ndecisions when appropriate.","ref":"code_of_conduct.html#enforcement-responsibilities"},{"type":"extras","title":"Scope - Code of Conduct","doc":"This Code of Conduct applies within all community spaces, and also applies when\nan individual is officially representing the community in public spaces.\nExamples of representing our community include using an official e-mail address,\nposting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Enforcement - Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported to the community leaders responsible for enforcement by \nopening an issue or contacting one or more of the project maintainers.\nAll complaints will be reviewed and investigated promptly and fairly.\n\nAll community leaders are obligated to respect the privacy and security of the\nreporter of any incident.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Enforcement Guidelines - Code of Conduct","doc":"Community leaders will follow these Community Impact Guidelines in determining\nthe consequences for any action they deem in violation of this Code of Conduct:\n\n#","ref":"code_of_conduct.html#enforcement-guidelines"},{"type":"extras","title":"1. Correction - Code of Conduct","doc":"**Community Impact**: Use of inappropriate language or other behavior deemed\nunprofessional or unwelcome in the community.\n\n**Consequence**: A private, written warning from community leaders, providing\nclarity around the nature of the violation and an explanation of why the\nbehavior was inappropriate. A public apology may be requested.\n\n#","ref":"code_of_conduct.html#1-correction"},{"type":"extras","title":"2. Warning - Code of Conduct","doc":"**Community Impact**: A violation through a single incident or series\nof actions.\n\n**Consequence**: A warning with consequences for continued behavior. No\ninteraction with the people involved, including unsolicited interaction with\nthose enforcing the Code of Conduct, for a specified period of time. This\nincludes avoiding interactions in community spaces as well as external channels\nlike social media. Violating these terms may lead to a temporary or\npermanent ban.\n\n#","ref":"code_of_conduct.html#2-warning"},{"type":"extras","title":"3. Temporary Ban - Code of Conduct","doc":"**Community Impact**: A serious violation of community standards, including\nsustained inappropriate behavior.\n\n**Consequence**: A temporary ban from any sort of interaction or public\ncommunication with the community for a specified period of time. No public or\nprivate interaction with the people involved, including unsolicited interaction\nwith those enforcing the Code of Conduct, is allowed during this period.\nViolating these terms may lead to a permanent ban.\n\n#","ref":"code_of_conduct.html#3-temporary-ban"},{"type":"extras","title":"4. Permanent Ban - Code of Conduct","doc":"**Community Impact**: Demonstrating a pattern of violation of community\nstandards, including sustained inappropriate behavior,  harassment of an\nindividual, or aggression toward or disparagement of classes of individuals.\n\n**Consequence**: A permanent ban from any sort of public interaction within\nthe community.","ref":"code_of_conduct.html#4-permanent-ban"},{"type":"extras","title":"Attribution - Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage],\nversion 2.0, available at\nhttps://www.contributor-covenant.org/version/2/0/code_of_conduct.html.\n\nCommunity Impact Guidelines were inspired by [Mozilla's code of conduct\nenforcement ladder](https://github.com/mozilla/diversity).\n\n[homepage]: https://www.contributor-covenant.org\n\nFor answers to common questions about this code of conduct, see the FAQ at\nhttps://www.contributor-covenant.org/faq. Translations are available at\nhttps://www.contributor-covenant.org/translations.","ref":"code_of_conduct.html#attribution"},{"type":"extras","title":"License","doc":"# MIT License\n\nCopyright (c) 2020 Paul Götze\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# MJML (Rust NIFs for Elixir)\n\n[![Build Status](https://github.com/adoptoposs/mjml_nif/workflows/Tests/badge.svg)](https://github.com/adoptoposs/mjml_nif/workflows/Tests/badge.svg)\n[![Module Version](https://img.shields.io/hexpm/v/mjml.svg)](https://hex.pm/packages/mjml)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/mjml/)\n[![Total Download](https://img.shields.io/hexpm/dt/mjml.svg)](https://hex.pm/packages/mjml)\n[![License](https://img.shields.io/hexpm/l/mjml.svg)](https://github.com/adoptoposs/mjml_nif/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/adoptoposs/mjml_nif.svg)](https://github.com/adoptoposs/mjml_nif/commits/master)\n\nNative Implemented Function (NIF) bindings for the [MJML](https://mjml.io) Rust implementation ([mrml](https://github.com/jdrouet/mrml)).","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"The package can be installed by adding `mjml` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:mjml, \"~> 3.0\"}\n  ]\nend\n```\n\nBy default **you don't need Rust installed** because the lib will try to download\na precompiled NIF file. In case you want to force compilation set the\n`MJML_BUILD` environment variable to `true` or `1`. Alternatively you can also set the\napplication env in order to force the build:\n\n```elixir\nconfig :rustler_precompiled, :force_build, mjml: true\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Overview","doc":"Transpile MJML templates to HTML with:\n\n```elixir\nmjml = \" ... \"\n{:ok, html} = Mjml.to_html(mjml)\n\n# For an invalid MJML template:\nmjml = \"something not MJML\"\n{:error, message} = Mjml.to_html(mjml)\n```\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Options - Overview","doc":"Available rendering options are:\n\n* `keep_comments` – when `false`, removes comments from the final HTML. Defaults to `true`.\n* `social_icon_path` – when given, uses this base path to generate social icon URLs.\n* `fonts` – a Map of font names and their URLs to a hosted CSS file.\n  When given, includes these fonts in the rendered HTML\n  (Note that only actually used fonts will show up!).\n  Defaults to `nil`, which will make the default font families available to\n  be used (Open Sans, Droid Sans, Lato, Roboto, and Ubuntu).\n\n```elixir\nmjml = \" ... \"\n\nopts = [\n  keep_comments: false,\n  social_icon_path: \"https://example.com/icons/\",\n  fonts: %{\n      \"Noto Color Emoji\": \"https://fonts.googleapis.com/css?family=Noto+Color+Emoji:400\"\n  }\n]\n\n{:ok, html} = Mjml.to_html(mjml, opts)\n```","ref":"readme.html#options"},{"type":"extras","title":"Contributing - Overview","doc":"We encourage you to contribute to mjml_nif.\nPlease check our [CONTRIBUTING.md](./CONTRIBUTING.md) guides for more information.\n\nThis project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to our [CODE_OF_CONDUCT.md](./CODE_OF_CONDUCT.md).","ref":"readme.html#contributing"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2020 Paul Götze\n\nThis work is free. You can redistribute it and/or modify it under the\nterms of the MIT License. See the [LICENSE.md](./LICENSE.md) file for more details.","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown"}